@@ -123,7 +123,11 @@ class Plugin(plugin.PluginBase):
         stage=plugin.Stages.STAGE_SETUP,
         name=odwhcons.Stages.DB_CONNECTION_SETUP,
         condition=lambda self: (
-            self.environment[odwhcons.CoreEnv.ENABLE]
+            self.environment[odwhcons.CoreEnv.ENABLE] and (
+                self.environment[
+                    osetupcons.CoreEnv.ACTION
+                ] != osetupcons.Const.ACTION_PROVISIONDB
+            )
         ),
     )
     def _setup(self):
@@ -167,7 +171,7 @@ class Plugin(plugin.PluginBase):
                 self.environment[
                     odwhcons.DBEnv.NEED_DBMSUPGRADE
                 ] = dbovirtutils.checkDBMSUpgrade()
-            except RuntimeError as e:
+            except RuntimeError:
                 self.logger.debug(
                     'Existing credential use failed',
                     exc_info=True,
